@@ -81,7 +81,8 @@
                 "tools-for-build/LineBreak.txt"
                 "tools-for-build/DerivedAge.txt"
                 "tools-for-build/allkeys.txt"
-                "tools-for-build/ConfusablesEdited.txt"
+                "tools-for-build/emoji-data.txt"
+                "tools-for-build/confusables.txt"
                 "tools-for-build/BidiMirroring.txt"
                 "tools-for-build/Blocks.txt"
                 "tools-for-build/Jamo.txt"
@@ -106,6 +107,8 @@
                  "output/DerivedAge.txt"
                  "output/DerivedNormalizationProps.txt"
                  "output/EastAsianWidth.txt"
+                 "output/emoji-data.txt"
+                 "output/confusables.txt"
                  "output/foldcases.lisp-expr"
                  "output/Jamo.txt"
                  "output/LineBreak.txt"
