@@ -1848,7 +1848,7 @@ function to be removed without further warning."
                                     body))
                             (setf (svref ,table-name ,typecode) #',fun-name))))
        (defmacro ,dispatch-name (&rest args)
-         (check-type (first args) symbol)
+         (aver (symbolp (first args)))
          (let ((tag (gensym "TAG")))
            `(funcall
              (truly-the function
@@ -1905,24 +1905,19 @@ function to be removed without further warning."
   (declare (index length))
   (when (and element-p contents-p)
     (error "Can't specify both :INITIAL-ELEMENT and :INITIAL-CONTENTS"))
-  ;; Explicitly compute a widetag with the weakness bit ORed in.
-  (let ((type (logior (ash vector-weak-flag array-flags-position) simple-vector-widetag)))
     ;; These allocation calls are the transforms of MAKE-ARRAY for a vector with
     ;; the respective initializing keyword arg. This is badly OAOO-violating and
     ;; almost makes me want to cry, but not quite enough for me to improve it.
-    (if contents-p
+  (if contents-p
         (let ((contents-length (length initial-contents)))
           (if (= length contents-length)
-              (replace (truly-the simple-vector
-                                  (allocate-vector #+ubsan nil type length length))
-                       initial-contents)
+              (replace (sb-c::allocate-weak-vector length) initial-contents)
               (error "~S has ~D elements, vector length is ~D."
                      :initial-contents contents-length length)))
-        (fill (truly-the simple-vector
-                         (allocate-vector #+ubsan nil type length length))
+        (fill (sb-c::allocate-weak-vector length)
               ;; 0 is the usual default, but NIL makes more sense for weak vectors
               ;; as it is the value assigned to broken hearts.
-              (if element-p initial-element nil)))))
+              (if element-p initial-element nil))))
 
 (defun weak-vector-p (x)
   (and (simple-vector-p x)
