@@ -237,7 +237,8 @@ sufficiently motivated to do lengthy fixes."
           ;; Scan roots as close as possible to GC-AND-SAVE, in case anything
           ;; prior causes compilation to occur into immobile space.
           ;; Failing to see all immobile code would miss some relocs.
-          #+immobile-code (sb-vm::choose-code-component-order root-structures)
+          ;; FIXME: this could work on non-x86, but it doesn't right now.
+          #+(and x86-64 immobile-code) (sb-vm::choose-code-component-order root-structures)
           ;; Must clear this cache if asm routines are movable.
           (setq sb-disassem::*assembler-routines-by-addr* nil
                 ;; and save some space by deleting the instruction decoding table
@@ -333,10 +334,10 @@ sufficiently motivated to do lengthy fixes."
   (float-deinit)
   (profile-deinit)
   (foreign-deinit)
-  (when (zerop (hash-table-count sb-kernel::*forward-referenced-wrappers*))
+  (when (zerop (hash-table-count sb-kernel::*forward-referenced-layouts*))
     ;; I think this table should always be empty but I'm not sure. If it is,
     ;; recreate it so that we don't preserve an empty vector taking up 16KB
-    (setq sb-kernel::*forward-referenced-wrappers* (make-hash-table :test 'equal)))
+    (setq sb-kernel::*forward-referenced-layouts* (make-hash-table :test 'equal)))
   ;; Clean up the simulated weak list of covered code components.
   (rplacd sb-c:*code-coverage-info*
           (delete-if-not #'weak-pointer-value (cdr sb-c:*code-coverage-info*)))
@@ -346,7 +347,7 @@ sufficiently motivated to do lengthy fixes."
   (clrhash sb-c::*emitted-full-calls*) ; Don't immortalize compiler's scratchpad
   ;; Perform static linkage. Functions become un-statically-linked
   ;; on demand, for TRACE, redefinition, etc.
-  #+immobile-code (sb-vm::statically-link-core)
+  #+(and immobile-code x86-64) (sb-vm::statically-link-core)
   (finalizers-deinit)
   ;; Try to shrink the pathname cache. It might be largely nulls
   (rebuild-pathname-cache)
@@ -665,22 +666,21 @@ sb-c::
        :immobile))
 
     (let* ((n (length ordering))
-           (array (make-alien int (1+ (* n 2)))))
+           (array (make-alien unsigned (1+ (* n 2)))))
       (loop for i below n
-            do (setf (deref array (* i 2))
-                     (get-lisp-obj-address (aref ordering i))))
+            do (setf (deref array (* i 2)) (get-lisp-obj-address (aref ordering i))))
       (setf (deref array (* n 2)) 0) ; null-terminate the array
       (setf (extern-alien "code_component_order" unsigned)
             (sap-int (alien-value-sap array)))))
 
   (multiple-value-bind (index relocs) (collect-immobile-code-relocs)
     (let* ((n (length index))
-           (array (make-alien int n)))
+           (array (make-alien unsigned n)))
       (dotimes (i n) (setf (deref array i) (aref index i)))
       (setf (extern-alien "immobile_space_reloc_index" unsigned)
             (sap-int (alien-value-sap array))))
     (let* ((n (length relocs))
-           (array (make-alien int n)))
+           (array (make-alien unsigned n)))
       (dotimes (i n) (setf (deref array i) (aref relocs i)))
       (setf (extern-alien "immobile_space_relocs" unsigned)
             (sap-int (alien-value-sap array))))))
