@@ -69,6 +69,7 @@
                  (unless (or (eq block tail)
                              (eq (block-component block) c))
                    (barf "~S is not in ~S." block c)))
+               #+(or)
                (let ((component-outer-loop (component-outer-loop c)))
                  (when (or (loop-blocks component-outer-loop)
                            (loop-inferiors component-outer-loop))
@@ -617,8 +618,13 @@
                      (if (template-conditional-p info) 0 (length rtypes))
                      (template-more-results-type info) "results")
       (check-tn-refs (vop-temps vop) vop t 0 t "temps")
-      (unless (= (length (vop-codegen-info vop))
-                 (template-info-arg-count info))
+      (unless (or (= (+ (length (vop-codegen-info vop))
+                        (if (typep (template-result-types info) '(cons (eql :conditional)))
+                            -1
+                            0))
+                     (template-info-arg-count info))
+                  ;; Allow these 2 allocator vops to take an undeclared info arg
+                  (member (vop-info-name info) '(sb-vm::fixed-alloc sb-vm::var-alloc)))
         (barf "wrong number of codegen info args in ~S" vop))))
   (values))
 
@@ -944,7 +950,7 @@
     (ctran (ctran-block thing))
     (node (node-block thing))
     (component (component-head thing))
-#|    (cloop (loop-head thing))|#
+    (cloop (loop-head thing))
     (integer (ctran-block (num-cont thing)))
     (functional (lambda-block (main-entry thing)))
     (null (error "Bad thing: ~S." thing))
@@ -970,6 +976,7 @@
                    (lvar-dynamic-extent lvar) (cont-num lvar) rest)))
 
 (defvar *debug-print-types* nil)
+(defvar *debug-print-vop-temps* nil)
 
 ;;; Print out the nodes in BLOCK in a format oriented toward
 ;;; representing what the code does.
@@ -1032,17 +1039,8 @@
            (let ((cleanup (entry-cleanup node)))
              (case (cleanup-kind cleanup)
                ((:dynamic-extent)
-                (format t "entry DX~{ v~D~}"
-                        (mapcar (lambda (lvar-or-cell)
-                                  (typecase lvar-or-cell
-                                    (cons
-                                     (cons (car lvar-or-cell)
-                                           (cont-num (cdr lvar-or-cell))))
-                                    (enclose
-                                     lvar-or-cell)
-                                    (t
-                                     (cont-num lvar-or-cell))))
-                                (cleanup-nlx-info cleanup))))
+                (format t "entry DX~{ ~D~}"
+                        (cleanup-nlx-info cleanup)))
                (t
                 (format t "entry ~S" (entry-exits node))))))
           (exit
@@ -1067,6 +1065,17 @@
            (write-string "enclose ")
            (dolist (leaf (enclose-funs node))
              (print-leaf leaf)
+             (when (lambda-p leaf)
+               (write-char #\space)
+               (let ((env (lambda-environment leaf)))
+                 (when env
+                   (write-string "{env:")
+                   (dolist (thing (environment-closure env))
+                     (write-char #\space)
+                     (etypecase thing
+                       (leaf (print-leaf thing))
+                       (nlx-info (princ thing))))
+                   (write-string "}"))))
              (write-char #\space))))
         (when (and *debug-print-types*
                    (valued-node-p node))
@@ -1132,6 +1141,11 @@
     (princ #\space)
     (pprint-indent :current 0)
     (print-operands (vop-args vop))
+    (when *debug-print-vop-temps*
+      (pprint-newline :linear)
+      (write-string "{temp: ")
+      (print-operands (vop-temps vop))
+      (princ #\}))
     (pprint-newline :linear)
     (when (vop-codegen-info vop)
       (case (vop-name vop)
@@ -1394,8 +1408,9 @@ is replaced with replacement."
                (gethash block block-labels)))
         (do-blocks (block component :both)
           (cond ((eq block (component-head component))
-                 (format stream "~a [label=head];"
-                         (block-label block)))
+                 (format stream "~a [label=\"head of component ~a\"];"
+                         (block-label block)
+                         (component-name component)))
                 ((eq block (component-tail component))
                  (format stream "~a [label=tail];"
                          (block-label block)))
