@@ -127,7 +127,9 @@
    #+x86-64
    ("Sub overflow" sub-overflow 1)
    ("Add overflow" signed-unsigned-add-overflow 1)
-   ("Sub overflow" sub-overflow2 2))
+   ("ADd overflow" add-overflow2 2)
+   ("Sub overflow" sub-overflow2 2)
+   ("Mul overflow" mul-overflow2 2))
   ;; (II) All the type specifiers X for which there is a unique internal
   ;;      error code corresponding to a primitive object-not-X-error.
   function
@@ -197,7 +199,7 @@
   sb-c::vop
   sb-c::basic-combination
   sb-sys:fd-stream
-  wrapper
+  layout
   (sb-assem:segment object-not-assem-segment)
   sb-c::cblock
   sb-disassem:disassem-state
