@@ -38,6 +38,8 @@ static inline int cs_mutex_lock(void* l) { EnterCriticalSection(l); return 1; }
 static inline int cs_mutex_unlock(void* l) { LeaveCriticalSection(l); return 1; }
 #define mutex_acquire(l) cs_mutex_lock(l)
 #define mutex_release(l) cs_mutex_unlock(l)
+#define CONDITION_VAR_WAIT(x,y) SleepConditionVariableCS(x,y,INFINITE)
+#define CONDITION_VAR_WAKE_ALL(x) WakeAllConditionVariable(x)
 #else
 #define thread_self() pthread_self()
 #define thread_equal(a,b) pthread_equal(a,b)
@@ -45,6 +47,8 @@ static inline int cs_mutex_unlock(void* l) { LeaveCriticalSection(l); return 1;
 #define mutex_acquire(l) !pthread_mutex_lock(l)
 #define mutex_release(l) !pthread_mutex_unlock(l)
 #define TryEnterCriticalSection(l) !pthread_mutex_trylock(l)
+#define CONDITION_VAR_WAIT(x,y) pthread_cond_wait(x,y)
+#define CONDITION_VAR_WAKE_ALL(x) pthread_cond_broadcast(x)
 #endif
 
 #else
@@ -99,15 +103,6 @@ void gc_state_unlock();
  * generally need customization.
  */
 
-#define odxprint(topic, fmt, ...)                       \
-    do                                                  \
-        if (dyndebug_config.dyndebug_##topic)           \
-            odxprint_fun(fmt "\n", ##__VA_ARGS__);      \
-    while (0)
-
-void odxprint_fun(const char *fmt, ...);
-void fshow_fun(void *ignored, const char *fmt, ...);
-
 /* Flags defined in a structure to avoid code duplication between
  * declaration and definition. */
 extern struct dyndebug_config {
@@ -129,19 +124,13 @@ extern int gencgc_verbose;
 
 void dyndebug_init(void);
 
-/* The following macros duplicate the expansion of odxprint, because the
- * extra level of parentheses around `args' prevents us from
- * implementing FSHOW in terms of odxprint directly.  (They also differ
- * in a newline.)
- */
-
-#if QSHOW
-# define FSHOW(args) \
-    do if (dyndebug_config.dyndebug_fshow) fshow_fun args; while (0)
-# define SHOW(string) FSHOW((stderr, "/%s\n", string))
+#if 0
+/* To see output from FSHOW - which is almost certainly a bad idea because it's
+ * quite likely to hinder your progress by causing deadlock in stdio - then change
+ * the preceding line to "#if 1" */
+# define FSHOW(args) fprintf args
 #else
 # define FSHOW(args)
-# define SHOW(string)
 #endif
 
 #ifdef _WIN64
@@ -212,16 +201,6 @@ is_lisp_pointer(lispobj obj)
 #endif
 }
 
-/* The standard pointer tagging scheme admits an optimization that cuts the number
- * of instructions down when testing for either 'a' or 'b' (or both) being a tagged
- * pointer, because the bitwise OR of two pointers is considered a pointer.
- * This trick is inadmissible for the PPC64 lowtag arrangement */
-#ifdef LISP_FEATURE_PPC64
-#define at_least_one_pointer_p(a,b) (is_lisp_pointer(a) || is_lisp_pointer(b))
-#else
-#define at_least_one_pointer_p(a,b) (is_lisp_pointer(a|b))
-#endif
-
 #include "fixnump.h"
 
 /* Is the Lisp object obj something with immediate nature (e.g. a
