@@ -11,8 +11,6 @@
 ;;;; absolutely no warranty. See the COPYING and CREDITS files for
 ;;;; more information.
 
-(in-package :cl-user)
-
 ;;; Exercise a compiler bug (by causing a call to ERROR).
 ;;;
 ;;; This bug was in sbcl-0.6.11.6.
@@ -29,7 +27,8 @@
 ;;; isn't declared as a variable, but to set its SYMBOL-VALUE anyway.
 ;;;
 ;;; This bug was in sbcl-0.6.11.13.
-(print (setq improperly-declared-var '(1 2)))
+(locally (declare (sb-ext:muffle-conditions warning))
+  (print (setq improperly-declared-var '(1 2))))
 (assert (equal (symbol-value 'improperly-declared-var) '(1 2)))
 (makunbound 'improperly-declared-var)
 ;;; This is a slightly different way of getting the same symptoms out
@@ -131,7 +130,7 @@
            (declare (type (simple-array (unsigned-byte 32) (*)) a))
            (declare (type (function (fixnum)) f))
            (funcall f (aref a 0))))
-    #-x86-64
+    #-64-bit
     (assert
      (eval `(let ((n (1+ most-positive-fixnum)))
               (if (not (typep n '(unsigned-byte 32)))
@@ -170,22 +169,46 @@
             ,@(loop for saetp across
                     sb-vm:*specialized-array-element-type-properties*
                     for specifier = (sb-vm:saetp-specifier saetp)
-                    for array = (make-array (if specifier 10 0)
-                                            :element-type specifier)
+                    for init = (cond ((member specifier '(character base-char))
+                                      '(:initial-element #\X))
+                                     ((eq specifier 't) '(:initial-element :hello))
+                                     (specifier
+                                      `(:initial-element
+                                        ,(sb-vm:saetp-initial-element-default saetp))))
+                    for array = (apply 'make-array (if specifier 10 0)
+                                       :element-type specifier init)
                     for make-array = `(make-array ,(if specifier 10 0)
-                                                  :element-type ',specifier)
+                                                  :element-type ',specifier
+                                                  ,@init)
                     collect `(assert (and (equal (type-of ,array)
                                                  ',(type-of array))
                                           (equalp ,array
                                                   ,make-array)))))))
     (make-tests)))
 
-(lambda () (the string (+ 1 x)))
+(defparameter *my-type-test-ran* 0)
+(deftype some-weird-type () '(satisfies my-thing-p))
+(defun my-thing-p (x)
+  (incf *my-type-test-ran*)
+  (member x '(nil :foo)))
 
-(lambda ()
-  (macrolet ((x (&rest args)
-               (declare (ignore args))
-               'a))
-    (let (a)
-      (declare (type vector a))
-      (x #.#'list))))
+(defun make-array-fill-nil ()
+  (sb-int:dx-let ((a (make-array 5 :initial-element nil
+                                 :element-type '(or (and complex) some-weird-type))))
+    (values (stack-allocated-p a)
+            *my-type-test-ran*)))
+
+(with-test (:name :splat-nil)
+  (multiple-value-bind (ok tested) (make-array-fill-nil)
+    ;; should not inhibit stack allocation, should check that NIL is OK
+    (assert (and ok (eql tested 1)))))
+
+(defun push-values-constants (k)
+  (let (*)
+    (if k
+        (eval k)
+        (load-time-value t))))
+
+(with-test (:name :push-values-constants)
+  (assert (eql (push-values-constants 1) 1))
+  (assert (eql (push-values-constants nil) t)))
