@@ -224,6 +224,7 @@
     (assert (= (sb-kernel:get-lisp-obj-address *pin-test-object*)
                *pin-test-object-address*))))
 
+(import 'sb-kernel:%make-lisp-obj)
 #+gencgc
 (defun ensure-code/data-separation ()
   (let* ((n-bits (+ sb-vm:next-free-page 10))
@@ -236,7 +237,7 @@
        ;; M-A-O disables GC, therefore GET-LISP-OBJ-ADDRESS is safe
        (let ((obj-addr (sb-kernel:get-lisp-obj-address obj))
              (array (cond ((member type `(,sb-vm:code-header-widetag
-                                          #+compact-instance-header
+                                          #+executable-funinstances
                                           ,sb-vm:funcallable-instance-widetag))
                            (incf total-code-size size)
                            code-bits)
@@ -251,6 +252,25 @@
                                                         (1- size))))
                do (setf (sbit array index) 1))))
      :dynamic)
+    (let ((p (position 1 (bit-and code-bits data-bits))))
+      (when p
+        (format t "~&code+data: page index ~d, generation ~D~%"
+                p (slot (deref sb-vm::page-table p) 'sb-vm::gen))
+        (assert (zerop (slot (deref sb-vm::page-table p) 'sb-vm::start)))
+        (let ((base (+ (* p sb-vm:gencgc-page-bytes)
+                       sb-vm:dynamic-space-start)))
+          ;; This mapping operation may fail if the page's first object is not at the base
+          ;; or it ends with a page-spanning object. But this diagnostic logic should
+          ;; never be invoked. If it is, you should find the cause of that rather than
+          ;; worry about this slightly dubious use of map-objects-in-range.
+          (sb-vm::map-objects-in-range
+           (lambda (obj widetag size)
+             (declare (ignore widetag size))
+             (format t "~x ~s~%" (sb-kernel:get-lisp-obj-address obj) (type-of obj)))
+           (%make-lisp-obj base)
+           (%make-lisp-obj (+ base
+                              (ash (slot (deref sb-vm::page-table p) 'sb-vm::words-used*)
+                                   sb-vm:word-shift)))))))
     (assert (not (find 1 (bit-and code-bits data-bits))))
     (let* ((code-bytes-consumed
              (* (count 1 code-bits) sb-vm:gencgc-page-bytes))
@@ -260,10 +280,7 @@
       ;; Some have as little as .5% space wasted.
       (assert (<= waste (* 3/100 code-bytes-consumed))))))
 
-
-
-(with-test (:name :code/data-separation
-            :skipped-on (not :gencgc))
+(with-test (:name :code/data-separation)
   (compile 'ensure-code/data-separation)
   (ensure-code/data-separation))
 
