@@ -324,8 +324,8 @@
           (list (sb-impl::info-env-count sb-int:*info-environment*)))))
 
 (defun structureish-classoid-ancestors (classoid)
-  (map 'list 'sb-kernel:wrapper-classoid
-       (sb-kernel:wrapper-inherits (sb-kernel:classoid-wrapper classoid))))
+  (map 'list 'sb-kernel:layout-classoid
+       (sb-kernel:layout-inherits (sb-kernel:classoid-layout classoid))))
 
 (defun globaldb-cleanup (initial-packages globaldb-summary)
   ;; Package deletion suffices to undo DEFVAR,DEFTYPE,DEFSETF,DEFUN,DEFMACRO
@@ -503,6 +503,33 @@
                             sb-kernel::%compiler-defclass))
             (sb-int:unencapsulate symbol 'defblah-guard)))))
     (makunbound '*allowed-inputs*)
+    ;; MUTEX-P could crash on a layoutless instance (tests may make such things).
+    ;; Normally a layoutless instance can never be see because user code can not
+    ;; publish an object until leaving its constructor, and a structure constructor
+    ;; wouldn't return before storing a layout. But MAP-ALLOCATED-OBJECTS finds it.
+    #+nil
+    (let* ((mutexes
+            (remove-if (lambda (x)
+                         (or (eq x sb-impl::*active-processes-lock*)
+                             (eq x sb-impl::*finalizer-lock*)
+                             #+nil (eq x sb-vm::*allocator-mutex*)))
+                       (sb-vm:list-allocated-objects :all :test #'sb-thread::mutex-p)))
+           (contended (remove-if
+                       (lambda (x)
+                         (or (atom (sb-thread::mutex-%name x))
+                             (zerop (cdr (sb-thread::mutex-%name x)))
+                             ;; finalizer thread is started and stopped often for tests.
+                             ;; No only is it annoying to see it in here, to be correct
+                             ;; we'd need to sum the times of all same-named mutexes.
+                             (string= (sb-thread:mutex-name x) "finalizer")))
+                       mutexes)))
+      (when contended
+        (format t "~&Most-contended mutexes:~%")
+        (dolist (x (sort contended #'> :key (lambda (x) (cdr (sb-thread::mutex-%name x)))))
+          (format t "~12d ~s ~S~%"
+                  (cdr (sb-thread::mutex-%name x))
+                  x
+                  (sb-kernel:generation-of x)))))
     ;; after all the files are done
     (append-failures)))
 
