@@ -58,14 +58,15 @@
         (setq lines (nbutlast lines)))
       ;; Remove safepoint traps
       (setq lines (remove-if (lambda (x) (search "; safepoint" x)) lines))
-      ;; If the last 4 lines are of the expected form
-      ;;   MOV RSP, RBP / CLC / POP RBP / RET
+      ;; If the last 3 lines are of the expected form
+      ;;   LEAVE / CLC / RET
       ;; then strip them out
       (if (and remove-epilogue
-               (every #'search
-                      '("MOV RSP, RBP" "CLC" "POP RBP" "RET")
-                      (subseq lines (- (length lines) 4))))
-          (butlast lines 4)
+               (let ((last3 (subseq lines (- (length lines) 3))))
+                 (and (search "LEAVE" (first last3))
+                      (search "CLC" (second last3))
+                      (search "RET" (third last3)))))
+          (butlast lines 3)
           lines)))
 (defun disasm-load (safety symbol)
   ;; This lambda has a name because if it doesn't, then the name
@@ -166,7 +167,7 @@
          (index
           (position "OBJECT-NOT-TYPE-ERROR" lines :test 'search)))
     (let ((line (nth (+ index 2) lines)))
-      (assert (search "; #<SB-KERNEL:WRAPPER " line))
+      (assert (search "; #<SB-KERNEL:LAYOUT " line))
       (assert (search " SB-ASSEM:LABEL" line)))))
 
 #+immobile-code ; uses SB-C::*COMPILE-TO-MEMORY-SPACE*
@@ -674,15 +675,15 @@
   ;; component.
   (let ((names
           (mapcar (lambda (x)
-                    (sb-kernel:classoid-name (sb-kernel:wrapper-classoid x)))
-                  (ctu:find-code-constants #'sb-kernel:%%typep :type 'sb-kernel:wrapper))))
+                    (sb-kernel:classoid-name (sb-kernel:layout-classoid x)))
+                  (ctu:find-code-constants #'sb-kernel:%%typep :type 'sb-kernel:layout))))
     (assert (null (set-difference names
                                   '(sb-kernel:ctype
                                     sb-kernel:unknown-type
                                     sb-kernel:fun-designator-type
                                     sb-c::abstract-lexenv
                                     sb-kernel::classoid-cell
-                                    sb-kernel:wrapper
+                                    sb-kernel:layout
                                     sb-kernel:classoid
                                     sb-kernel:built-in-classoid
                                     #-immobile-space null))))))
@@ -701,7 +702,7 @@
      (loop for line in (split-string (with-output-to-string (string)
                                        (disassemble f :stream string))
                                      #\newline)
-             thereis (and (search "WRAPPER for" line)
+             thereis (and (search "LAYOUT for" line)
                           (search "CMP DWORD PTR" line)))))
 
 (with-test (:name :thread-local-unbound)
@@ -712,7 +713,7 @@
 #+immobile-code
 (with-test (:name :debug-fun-from-pc-more-robust)
   ;; This test verifies that debug-fun-from-pc does not croak when the PC points
-  ;; within a trampoline allocated to wrap a closure in a simple-funifying wrapper
+  ;; within a trampoline allocated to wrap a closure in a simple-funifying layout
   ;; for installation into a global symbol.
   (let ((closure (funcall (compile nil '(lambda (x)  (lambda () x))) 0))
         (symbol (gensym)))
@@ -949,6 +950,7 @@
                     (when (/= linecount expect-n)
                       (warn "~S was ~d is ~d" type expect-n linecount))))))))))
 
+#+nil ; gotta figure out how to make this insensitive to standard asm boilerplate
 (with-test (:name :many-interesting-array-types
                   :skipped-on (:or (:not :sb-unicode)
                                    (:not :immobile-space)))
